using System;

namespace Syntriax.Engine.Core.Abstract;

/// <summary>
/// Indicates the object is an <see cref="IAssignable"/> with an assignable <see cref="ITransform"/> field.
/// </summary>
public interface IAssignableGameManager : IAssignable
{
    /// <summary>
    /// Callback triggered when the <see cref="IGameManager"/> value has has been assigned a new value.
    /// </summary>
    Action<IAssignableGameManager>? OnGameManagerAssigned { get; set; }

    /// <inheritdoc cref="IGameManager" />
    IGameManager GameManager { get; }

    /// <summary>
    /// Assign a value to the <see cref="IGameManager"/> field of this object
    /// </summary>
    /// <param name="gameManager">New <see cref="IGameManager"/> to assign.</param>
    /// <returns> 
    /// <see cref="true"/>, if the value given assigned successfully assigned, <see cref="false"/> if not.
    /// </returns>
    bool Assign(IGameManager gameManager);
}
